==> haskell-invariant-0.5.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: invariant
version: 0.5.1
id: invariant-0.5.1-HLc5ufkyxb9qFJ25FebEV
key: invariant-0.5.1-HLc5ufkyxb9qFJ25FebEV
license: BSD-2-Clause
maintainer: Nicolas Frisby <nicolas.frisby@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Nicolas Frisby <nicolas.frisby@gmail.com>
homepage: https://github.com/nfrisby/invariant-functors
synopsis: Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).
    .
    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":
    .
    <http://comonad.com/reader/2008/rotten-bananas/>
category: Control, Data
abi: 1a5dee42cfc018a7cfc5f469ce1c18ed
exposed: True
exposed-modules:
    Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules: Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/invariant-0.5.1
hs-libraries: HSinvariant-0.5.1-HLc5ufkyxb9qFJ25FebEV
depends:
    array-0.5.2.0 base-4.11.1.0 bifunctors-5.5.3-DfLKZddWnIEB6abRlxmEkC
    comonad-5.0.4-6BvCuhx7i312Moy5XX16V2 containers-0.5.11.0
    contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI ghc-prim-0.5.2.0
    profunctors-5.3-9FfinDuGLWFA0z8WCPFmPD
    StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ stm-2.4.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO template-haskell-2.13.0.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bifunctors-5.5.3-DfLKZddWnIEB6abRlxmEkC=295557de758901ec7b2a2a06ded5bb97
             comonad-5.0.4-6BvCuhx7i312Moy5XX16V2=9c90e8f94411c9626a7e8a62a1f015de
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI=d2f13618f92bbccf0540968a185d3c43
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             profunctors-5.3-9FfinDuGLWFA0z8WCPFmPD=c4f5caccd7270609435ed7e692ca0cda
             StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ=14f2184827d9ccd91edef0e6749877d7
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=4938497122b3b44bd39134a6de0cb043
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
haddock-interfaces: /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html: /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-invariant-0.5.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: invariant
version: 0.5.1
id: invariant-0.5.1-FMuTJ5crY3GLJ3eqNkJyba
key: invariant-0.5.1-FMuTJ5crY3GLJ3eqNkJyba
license: BSD-2-Clause
maintainer: Nicolas Frisby <nicolas.frisby@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Nicolas Frisby <nicolas.frisby@gmail.com>
homepage: https://github.com/nfrisby/invariant-functors
synopsis: Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).
    .
    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":
    .
    <http://comonad.com/reader/2008/rotten-bananas/>
category: Control, Data
abi: 23b4a73def33ff1806b0c49b433eabe3
exposed: True
exposed-modules:
    Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules: Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/invariant-0.5.1
hs-libraries: HSinvariant-0.5.1-FMuTJ5crY3GLJ3eqNkJyba
depends:
    array-0.5.2.0 base-4.11.1.0 bifunctors-5.5.3-BIgJKb8FSuPAayKoWZoZXs
    comonad-5.0.4-G74MNGthp8MIbDjNAMuYxQ containers-0.5.11.0
    contravariant-1.5-5VBqEYOPGpyDW8QIali4BA ghc-prim-0.5.2.0
    profunctors-5.3-3u867uKeeneFGUkrebkTSU
    StateVar-1.1.1.1-5zTmcSrVbN7I4w3ZMeZaTb stm-2.4.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO template-haskell-2.13.0.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bifunctors-5.5.3-BIgJKb8FSuPAayKoWZoZXs=0426fbb9242519da49cd2883092459ef
             comonad-5.0.4-G74MNGthp8MIbDjNAMuYxQ=6066a8b25d542e863756d32fb8ed7569
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             profunctors-5.3-3u867uKeeneFGUkrebkTSU=7c1592d4b10059df053f39319b70fed8
             StateVar-1.1.1.1-5zTmcSrVbN7I4w3ZMeZaTb=b777c54e6eb83c2075ba969a9e5dd06d
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=4938497122b3b44bd39134a6de0cb043
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
haddock-interfaces: /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html: /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
